==> jc-1.4.0.tar.gz: soot/toolkits/scalar/ArraySparseSet__24SparseArrayList.h <==
// class soot.toolkits.scalar.ArraySparseSet$SparseArrayList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class ed5effcdfd9cdf24 soot_toolkits_scalar_ArraySparseSet__24SparseArrayList

// header file dependencies
// @dep_header java_util_AbstractList

#include "java/util/AbstractList.h"

#ifndef _JC_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList_H_
#define _JC_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_refs	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_refs;
typedef struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_nonrefs	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$refs	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$refs;
typedef struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$nonrefs	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$nonrefs;
typedef struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object;

typedef const struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vmethods	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vmethods;
typedef const struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtable	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtable;
typedef const struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtype	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method$_init$154a766f8ebd690f(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *, struct _jc_object_array *, jint);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method$get$a706240e1333824b(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *, jint);
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method$set$21145a3aa89a3e6d(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *, jint, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method_info$get$a706240e1333824b;
extern _jc_method _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method_info$set$21145a3aa89a3e6d;
extern _jc_method _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *);
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *, jint);
	struct _jc_java_lang_Object$object	*(*set$21145a3aa89a3e6d)(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *, jint, struct _jc_java_lang_Object$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vmethods	soot_toolkits_scalar_ArraySparseSet__24SparseArrayList;
};

// Vtype
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_refs {
	_jc_object_array	*array;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$refs {
    _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_refs	soot_toolkits_scalar_ArraySparseSet__24SparseArrayList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_nonrefs {
	jint	realSize;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_nonrefs	soot_toolkits_scalar_ArraySparseSet__24SparseArrayList;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object {
	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtype	*vtype;
	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtype _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_ArraySparseSet__24SparseArrayList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$class_object;

#endif	/* _JC_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/ArraySparseSet__24SparseArrayList.h <==
// class soot.toolkits.scalar.ArraySparseSet$SparseArrayList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class ed5effcdfd9cdf24 soot_toolkits_scalar_ArraySparseSet__24SparseArrayList

// header file dependencies
// @dep_header java_util_AbstractList

#include "java/util/AbstractList.h"

#ifndef _JC_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList_H_
#define _JC_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_refs	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_refs;
typedef struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_nonrefs	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$refs	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$refs;
typedef struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$nonrefs	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$nonrefs;
typedef struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object;

typedef const struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vmethods	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vmethods;
typedef const struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtable	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtable;
typedef const struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtype	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method$_init$154a766f8ebd690f(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *, struct _jc_object_array *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method$get$a706240e1333824b(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method$set$21145a3aa89a3e6d(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method_info$get$a706240e1333824b;
extern _jc_method _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method_info$set$21145a3aa89a3e6d;
extern _jc_method _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*set$21145a3aa89a3e6d)(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vmethods	soot_toolkits_scalar_ArraySparseSet__24SparseArrayList;
};

// Vtype
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_refs {
	_jc_object_array	*array;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$refs {
    _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_refs	soot_toolkits_scalar_ArraySparseSet__24SparseArrayList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_nonrefs {
	jint	realSize;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$sub_nonrefs	soot_toolkits_scalar_ArraySparseSet__24SparseArrayList;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$object {
	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtype	*vtype;
	_jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$vtype _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_ArraySparseSet__24SparseArrayList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList$class_object;

#endif	/* _JC_soot_toolkits_scalar_ArraySparseSet__24SparseArrayList_H_ */
